Class FunctionServiceSettings
java.lang.Object
com.google.api.gax.rpc.ClientSettings<FunctionServiceSettings>
com.google.cloud.functions.v2alpha.FunctionServiceSettings
@BetaApi
@Generated("by gapic-generator-java")
public class FunctionServiceSettings
extends ClientSettings<FunctionServiceSettings>
Settings class to configure an instance of
FunctionServiceClient.
The default instance has everything set to sensible defaults:
- The default service address (cloudfunctions.googleapis.com) and default port (443) are used.
- Credentials are acquired automatically through Application Default Credentials.
- Retries are configured for idempotent methods but not for non-idempotent methods.
The builder of this class is recursive, so contained classes are themselves builders. When build() is called, the tree of builders is called to create the complete settings object.
For example, to set the [RetrySettings](https://cloud.google.com/java/docs/reference/gax/latest/com.google.api.gax.retrying.RetrySettings) of getFunction:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
FunctionServiceSettings.Builder functionServiceSettingsBuilder =
FunctionServiceSettings.newBuilder();
functionServiceSettingsBuilder
.getFunctionSettings()
.setRetrySettings(
functionServiceSettingsBuilder
.getFunctionSettings()
.getRetrySettings()
.toBuilder()
.setInitialRetryDelayDuration(Duration.ofSeconds(1))
.setInitialRpcTimeoutDuration(Duration.ofSeconds(5))
.setMaxAttempts(5)
.setMaxRetryDelayDuration(Duration.ofSeconds(30))
.setMaxRpcTimeoutDuration(Duration.ofSeconds(60))
.setRetryDelayMultiplier(1.3)
.setRpcTimeoutMultiplier(1.5)
.setTotalTimeoutDuration(Duration.ofSeconds(300))
.build());
FunctionServiceSettings functionServiceSettings = functionServiceSettingsBuilder.build();
Please refer to the [Client Side Retry
Guide](https://docs.cloud.google.com/java/docs/client-retries) for additional support in setting
retries.
To configure the RetrySettings of a Long Running Operation method, create an OperationTimedPollAlgorithm object and update the RPC's polling algorithm. For example, to configure the RetrySettings for createFunction:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
FunctionServiceSettings.Builder functionServiceSettingsBuilder =
FunctionServiceSettings.newBuilder();
TimedRetryAlgorithm timedRetryAlgorithm =
OperationalTimedPollAlgorithm.create(
RetrySettings.newBuilder()
.setInitialRetryDelayDuration(Duration.ofMillis(500))
.setRetryDelayMultiplier(1.5)
.setMaxRetryDelayDuration(Duration.ofMillis(5000))
.setTotalTimeoutDuration(Duration.ofHours(24))
.build());
functionServiceSettingsBuilder
.createClusterOperationSettings()
.setPollingAlgorithm(timedRetryAlgorithm)
.build();
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classBuilder for FunctionServiceSettings. -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedFunctionServiceSettings(FunctionServiceSettings.Builder settingsBuilder) -
Method Summary
Modifier and TypeMethodDescriptionstatic final FunctionServiceSettingsReturns the object with the settings used for calls to createFunction.Returns the object with the settings used for calls to createFunction.Returns a builder for the default credentials for this service.Returns a builder for the default ExecutorProvider for this service.Returns a builder for the default gRPC ChannelProvider for this service.Returns a builder for the default REST ChannelProvider for this service.static TransportChannelProviderOperationCallSettings<DeleteFunctionRequest,com.google.protobuf.Empty, OperationMetadata> Returns the object with the settings used for calls to deleteFunction.Returns the object with the settings used for calls to deleteFunction.Returns the object with the settings used for calls to generateDownloadUrl.Returns the object with the settings used for calls to generateUploadUrl.static StringReturns the default service endpoint.Returns the default service scopes.Returns the object with the settings used for calls to getFunction.Returns the object with the settings used for calls to getIamPolicy.PagedCallSettings<ListFunctionsRequest,ListFunctionsResponse, FunctionServiceClient.ListFunctionsPagedResponse> Returns the object with the settings used for calls to listFunctions.PagedCallSettings<ListLocationsRequest,ListLocationsResponse, FunctionServiceClient.ListLocationsPagedResponse> Returns the object with the settings used for calls to listLocations.Returns the object with the settings used for calls to listRuntimes.Returns a new gRPC builder for this class.newBuilder(ClientContext clientContext) Returns a new builder for this class.Returns a new REST builder for this class.Returns the object with the settings used for calls to setIamPolicy.Returns the object with the settings used for calls to testIamPermissions.Returns a builder containing all the values of this settings class.Returns the object with the settings used for calls to updateFunction.Returns the object with the settings used for calls to updateFunction.Methods inherited from class com.google.api.gax.rpc.ClientSettings
getApiKey, getBackgroundExecutorProvider, getClock, getCredentialsProvider, getEndpoint, getExecutorProvider, getGdchApiAudience, getHeaderProvider, getInternalHeaderProvider, getQuotaProjectId, getStubSettings, getTransportChannelProvider, getUniverseDomain, getWatchdogCheckInterval, getWatchdogCheckIntervalDuration, getWatchdogProvider, toString
-
Constructor Details
-
FunctionServiceSettings
protected FunctionServiceSettings(FunctionServiceSettings.Builder settingsBuilder) throws IOException - Throws:
IOException
-
-
Method Details
-
getFunctionSettings
Returns the object with the settings used for calls to getFunction. -
listFunctionsSettings
public PagedCallSettings<ListFunctionsRequest,ListFunctionsResponse, listFunctionsSettings()FunctionServiceClient.ListFunctionsPagedResponse> Returns the object with the settings used for calls to listFunctions. -
createFunctionSettings
Returns the object with the settings used for calls to createFunction. -
createFunctionOperationSettings
public OperationCallSettings<CreateFunctionRequest,Function, createFunctionOperationSettings()OperationMetadata> Returns the object with the settings used for calls to createFunction. -
updateFunctionSettings
Returns the object with the settings used for calls to updateFunction. -
updateFunctionOperationSettings
public OperationCallSettings<UpdateFunctionRequest,Function, updateFunctionOperationSettings()OperationMetadata> Returns the object with the settings used for calls to updateFunction. -
deleteFunctionSettings
Returns the object with the settings used for calls to deleteFunction. -
deleteFunctionOperationSettings
public OperationCallSettings<DeleteFunctionRequest,com.google.protobuf.Empty, deleteFunctionOperationSettings()OperationMetadata> Returns the object with the settings used for calls to deleteFunction. -
generateUploadUrlSettings
public UnaryCallSettings<GenerateUploadUrlRequest,GenerateUploadUrlResponse> generateUploadUrlSettings()Returns the object with the settings used for calls to generateUploadUrl. -
generateDownloadUrlSettings
public UnaryCallSettings<GenerateDownloadUrlRequest,GenerateDownloadUrlResponse> generateDownloadUrlSettings()Returns the object with the settings used for calls to generateDownloadUrl. -
listRuntimesSettings
Returns the object with the settings used for calls to listRuntimes. -
listLocationsSettings
public PagedCallSettings<ListLocationsRequest,ListLocationsResponse, listLocationsSettings()FunctionServiceClient.ListLocationsPagedResponse> Returns the object with the settings used for calls to listLocations. -
setIamPolicySettings
Returns the object with the settings used for calls to setIamPolicy. -
getIamPolicySettings
Returns the object with the settings used for calls to getIamPolicy. -
testIamPermissionsSettings
public UnaryCallSettings<TestIamPermissionsRequest,TestIamPermissionsResponse> testIamPermissionsSettings()Returns the object with the settings used for calls to testIamPermissions. -
create
public static final FunctionServiceSettings create(FunctionServiceStubSettings stub) throws IOException - Throws:
IOException
-
defaultExecutorProviderBuilder
Returns a builder for the default ExecutorProvider for this service. -
getDefaultEndpoint
Returns the default service endpoint. -
getDefaultServiceScopes
Returns the default service scopes. -
defaultCredentialsProviderBuilder
Returns a builder for the default credentials for this service. -
defaultGrpcTransportProviderBuilder
Returns a builder for the default gRPC ChannelProvider for this service. -
defaultHttpJsonTransportProviderBuilder
@BetaApi public static InstantiatingHttpJsonChannelProvider.Builder defaultHttpJsonTransportProviderBuilder()Returns a builder for the default REST ChannelProvider for this service. -
defaultTransportChannelProvider
-
defaultApiClientHeaderProviderBuilder
-
newBuilder
Returns a new gRPC builder for this class. -
newHttpJsonBuilder
Returns a new REST builder for this class. -
newBuilder
Returns a new builder for this class. -
toBuilder
Returns a builder containing all the values of this settings class.- Specified by:
toBuilderin classClientSettings<FunctionServiceSettings>
-