Class FunctionServiceSettings.Builder
java.lang.Object
com.google.api.gax.rpc.ClientSettings.Builder<FunctionServiceSettings,FunctionServiceSettings.Builder>
com.google.cloud.functions.v2alpha.FunctionServiceSettings.Builder
- Enclosing class:
- FunctionServiceSettings
public static class FunctionServiceSettings.Builder
extends ClientSettings.Builder<FunctionServiceSettings,FunctionServiceSettings.Builder>
Builder for FunctionServiceSettings.
-
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedBuilder()protectedBuilder(ClientContext clientContext) protectedBuilder(FunctionServiceSettings settings) protectedBuilder(FunctionServiceStubSettings.Builder stubSettings) -
Method Summary
Modifier and TypeMethodDescriptionapplyToAllUnaryMethods(ApiFunction<UnaryCallSettings.Builder<?, ?>, Void> settingsUpdater) Applies the given settings updater function to all of the unary API methods in this service.build()Returns the builder for the settings used for calls to createFunction.Returns the builder for the settings used for calls to createFunction.OperationCallSettings.Builder<DeleteFunctionRequest,com.google.protobuf.Empty, OperationMetadata> Returns the builder for the settings used for calls to deleteFunction.Returns the builder for the settings used for calls to deleteFunction.Returns the builder for the settings used for calls to generateDownloadUrl.Returns the builder for the settings used for calls to generateUploadUrl.Returns the builder for the settings used for calls to getFunction.Returns the builder for the settings used for calls to getIamPolicy.PagedCallSettings.Builder<ListFunctionsRequest,ListFunctionsResponse, FunctionServiceClient.ListFunctionsPagedResponse> Returns the builder for the settings used for calls to listFunctions.PagedCallSettings.Builder<ListLocationsRequest,ListLocationsResponse, FunctionServiceClient.ListLocationsPagedResponse> Returns the builder for the settings used for calls to listLocations.Returns the builder for the settings used for calls to listRuntimes.Returns the builder for the settings used for calls to setIamPolicy.Returns the builder for the settings used for calls to testIamPermissions.Returns the builder for the settings used for calls to updateFunction.Returns the builder for the settings used for calls to updateFunction.Methods inherited from class com.google.api.gax.rpc.ClientSettings.Builder
applyToAllUnaryMethods, getApiKey, getBackgroundExecutorProvider, getClock, getCredentialsProvider, getEndpoint, getExecutorProvider, getGdchApiAudience, getHeaderProvider, getInternalHeaderProvider, getQuotaProjectId, getStubSettings, getTransportChannelProvider, getWatchdogCheckInterval, getWatchdogCheckIntervalDuration, getWatchdogProvider, self, setApiKey, setBackgroundExecutorProvider, setClock, setCredentialsProvider, setEndpoint, setExecutorProvider, setGdchApiAudience, setHeaderProvider, setInternalHeaderProvider, setQuotaProjectId, setTransportChannelProvider, setUniverseDomain, setWatchdogCheckInterval, setWatchdogCheckIntervalDuration, setWatchdogProvider, toString
-
Constructor Details
-
Builder
- Throws:
IOException
-
Builder
-
Builder
-
Builder
-
-
Method Details
-
getStubSettingsBuilder
-
applyToAllUnaryMethods
public FunctionServiceSettings.Builder applyToAllUnaryMethods(ApiFunction<UnaryCallSettings.Builder<?, ?>, Void> settingsUpdater) Applies the given settings updater function to all of the unary API methods in this service.Note: This method does not support applying settings to streaming methods.
-
getFunctionSettings
Returns the builder for the settings used for calls to getFunction. -
listFunctionsSettings
public PagedCallSettings.Builder<ListFunctionsRequest,ListFunctionsResponse, listFunctionsSettings()FunctionServiceClient.ListFunctionsPagedResponse> Returns the builder for the settings used for calls to listFunctions. -
createFunctionSettings
Returns the builder for the settings used for calls to createFunction. -
createFunctionOperationSettings
public OperationCallSettings.Builder<CreateFunctionRequest,Function, createFunctionOperationSettings()OperationMetadata> Returns the builder for the settings used for calls to createFunction. -
updateFunctionSettings
Returns the builder for the settings used for calls to updateFunction. -
updateFunctionOperationSettings
public OperationCallSettings.Builder<UpdateFunctionRequest,Function, updateFunctionOperationSettings()OperationMetadata> Returns the builder for the settings used for calls to updateFunction. -
deleteFunctionSettings
Returns the builder for the settings used for calls to deleteFunction. -
deleteFunctionOperationSettings
public OperationCallSettings.Builder<DeleteFunctionRequest,com.google.protobuf.Empty, deleteFunctionOperationSettings()OperationMetadata> Returns the builder for the settings used for calls to deleteFunction. -
generateUploadUrlSettings
public UnaryCallSettings.Builder<GenerateUploadUrlRequest,GenerateUploadUrlResponse> generateUploadUrlSettings()Returns the builder for the settings used for calls to generateUploadUrl. -
generateDownloadUrlSettings
public UnaryCallSettings.Builder<GenerateDownloadUrlRequest,GenerateDownloadUrlResponse> generateDownloadUrlSettings()Returns the builder for the settings used for calls to generateDownloadUrl. -
listRuntimesSettings
Returns the builder for the settings used for calls to listRuntimes. -
listLocationsSettings
public PagedCallSettings.Builder<ListLocationsRequest,ListLocationsResponse, listLocationsSettings()FunctionServiceClient.ListLocationsPagedResponse> Returns the builder for the settings used for calls to listLocations. -
setIamPolicySettings
Returns the builder for the settings used for calls to setIamPolicy. -
getIamPolicySettings
Returns the builder for the settings used for calls to getIamPolicy. -
testIamPermissionsSettings
public UnaryCallSettings.Builder<TestIamPermissionsRequest,TestIamPermissionsResponse> testIamPermissionsSettings()Returns the builder for the settings used for calls to testIamPermissions. -
build
- Specified by:
buildin classClientSettings.Builder<FunctionServiceSettings,FunctionServiceSettings.Builder> - Throws:
IOException
-