Uses of Class
com.google.cloud.functions.v2alpha.FunctionServiceClient.ListLocationsPagedResponse
Packages that use FunctionServiceClient.ListLocationsPagedResponse
Package
Description
A client to Cloud Functions API
-
Uses of FunctionServiceClient.ListLocationsPagedResponse in com.google.cloud.functions.v2alpha
Methods in com.google.cloud.functions.v2alpha that return FunctionServiceClient.ListLocationsPagedResponseModifier and TypeMethodDescriptionFunctionServiceClient.listLocations(ListLocationsRequest request) Lists information about the supported locations for this service.Methods in com.google.cloud.functions.v2alpha that return types with arguments of type FunctionServiceClient.ListLocationsPagedResponseModifier and TypeMethodDescriptionFunctionServiceClient.ListLocationsPagedResponse.createAsync(PageContext<ListLocationsRequest, ListLocationsResponse, Location> context, ApiFuture<ListLocationsResponse> futureResponse) FunctionServiceClient.listLocationsPagedCallable()Lists information about the supported locations for this service.PagedCallSettings.Builder<ListLocationsRequest,ListLocationsResponse, FunctionServiceClient.ListLocationsPagedResponse> FunctionServiceSettings.Builder.listLocationsSettings()Returns the builder for the settings used for calls to listLocations.PagedCallSettings<ListLocationsRequest,ListLocationsResponse, FunctionServiceClient.ListLocationsPagedResponse> FunctionServiceSettings.listLocationsSettings()Returns the object with the settings used for calls to listLocations. -
Uses of FunctionServiceClient.ListLocationsPagedResponse in com.google.cloud.functions.v2alpha.stub
Methods in com.google.cloud.functions.v2alpha.stub that return types with arguments of type FunctionServiceClient.ListLocationsPagedResponseModifier and TypeMethodDescriptionFunctionServiceStub.listLocationsPagedCallable()GrpcFunctionServiceStub.listLocationsPagedCallable()HttpJsonFunctionServiceStub.listLocationsPagedCallable()PagedCallSettings.Builder<ListLocationsRequest,ListLocationsResponse, FunctionServiceClient.ListLocationsPagedResponse> FunctionServiceStubSettings.Builder.listLocationsSettings()Returns the builder for the settings used for calls to listLocations.PagedCallSettings<ListLocationsRequest,ListLocationsResponse, FunctionServiceClient.ListLocationsPagedResponse> FunctionServiceStubSettings.listLocationsSettings()Returns the object with the settings used for calls to listLocations.